### Encoding: latin1

### Name: difGenLord
### Title: Generalized Lord's chi-square DIF method
### Aliases: difGenLord plot.GenLord print.GenLord


### ** Examples

# Loading of the verbal data
data(verbal)
attach(verbal)

# Creating four groups according to gender ("Man" or "Woman") and trait 
# anger score ("Low" or "High")
group<-rep("WomanLow",nrow(verbal))
group[Anger>20 & Gender==0]<-"WomanHigh"
group[Anger<=20 & Gender==1]<-"ManLow"
group[Anger>20 & Gender==1]<-"ManHigh"

# New data set
Verbal<-cbind(verbal[,1:24],group)

# Reference group: "WomanLow"
names<-c("WomanHigh","ManLow","ManHigh")

# Three equivalent settings of the data matrix and the group membership
# 1PL model, "ltm" engine (remove #)

# difGenLord(Verbal, group=25, focal.names=names, model="1PL")
# difGenLord(Verbal, group="group", focal.name=names, model="1PL")
difGenLord(Verbal[,1:24], group=Verbal[,25], focal.names=names, 
model="1PL")

# 1PL model, "lme4" engine (remove #)

# difGenLord(Verbal, group="group", focal.name=names, model="1PL", 
# engine="lme4")

# With item purification (remove #)

# difGenLord(Verbal, group=25, focal.names=names, model="1PL", purify=TRUE)

# Splitting the data into the four subsets according to "group"
data0<-data1<-data2<-data3<-NULL
for (i in 1:nrow(verbal)){
if (group[i]=="WomanLow") data0<-rbind(data0,as.numeric(verbal[i,1:24]))
if (group[i]=="WomanHigh") data1<-rbind(data1,as.numeric(verbal[i,1:24]))
if (group[i]=="ManLow") data2<-rbind(data2,as.numeric(verbal[i,1:24]))
if (group[i]=="ManHigh") data3<-rbind(data3,as.numeric(verbal[i,1:24]))
}

# Estimation of the item parameters (1PL model)
m0.1PL<-itemParEst(data0, model="1PL")
m1.1PL<-itemParEst(data1, model="1PL")
m2.1PL<-itemParEst(data2, model="1PL")
m3.1PL<-itemParEst(data3, model="1PL")

# Merging the item parameters WITHOUT rescaling
irt.noscale<-rbind(m0.1PL,m1.1PL,m2.1PL,m3.1PL)
rownames(irt.noscale)<-rep(colnames(verbal[,1:24]),4)

# merging the item parameters WITH rescaling
irt.scale<-rbind(m0.1PL, itemRescale(m0.1PL,m1.1PL),
itemRescale(m0.1PL,m2.1PL) ,itemRescale(m0.1PL,m3.1PL))
rownames(irt.scale)<-rep(colnames(verbal[,1:24]),4)

# Equivalent calculations
difGenLord(irtParam=irt.noscale, nrFocal=3, same.scale=FALSE)
difGenLord(irtParam=irt.scale, nrFocal=3, same.scale=TRUE)

# With item purification
difGenLord(irtParam=irt.noscale, nrFocal=3, same.scale=FALSE, purify=TRUE)



