### Encoding: latin1

### Name: difRaju
### Title: Raju's area DIF method
### Aliases: difRaju plot.Raj print.Raj


### ** Examples

# Loading of the verbal data
data(verbal)
attach(verbal)

# Excluding the "Anger" variable
verbal<-verbal[colnames(verbal)!="Anger"]

# Three equivalent settings of the data matrix and the group membership 
# (1PL model, "ltm" engine) (remove #)
difRaju(verbal, group=25, focal.name=1, model="1PL")
# difRaju(verbal, group="Gender", focal.name=1, model="1PL")
# difRaju(verbal[,1:24], group=verbal[,25], focal.name=1, model="1PL")

# (1PL model, "lme4" engine) (remove #)
# difRaju(verbal, group="Gender", focal.name=1, model="1PL", 
# engine="lme4")

# 2PL model (remove #)
# difRaju(verbal, group="Gender", focal.name=1, model="2PL")

# 3PL model with all pseudo-guessing parameters constrained to 0.05
# (remove #)
# difRaju(verbal, group="Gender", focal.name=1, model="3PL", c=0.05)

# Same models, with item purification (remove #)
# difRaju(verbal, group="Gender", focal.name=1, model="1PL", purify=TRUE)
# difRaju(verbal, group="Gender", focal.name=1, model="2PL", purify=TRUE)
# difRaju(verbal, group="Gender", focal.name=1, model="3PL", c=0.05, 
# purify=TRUE)

## Splitting the data into reference and focal groups
nF<-sum(Gender)
nR<-nrow(verbal)-nF
data.ref<-verbal[,1:24][order(Gender),][1:nR,]
data.focal<-verbal[,1:24][order(Gender),][(nR+1):(nR+nF),]

## Pre-estimation of the item parameters (1PL model, "ltm" engine)
item.1PL<-rbind(itemParEst(data.ref,model="1PL"),
itemParEst(data.focal,model="1PL"))
difRaju(irtParam=item.1PL,same.scale=FALSE)

## Pre-estimation of the item parameters (1PL model, "lme4" engine)
# (remove #)
# item.1PL<-rbind(itemParEst(data.ref, model="1PL", engine="lme4"),
# itemParEst(data.focal, model="1PL", engine="lme4"))
# difRaju(irtParam=item.1PL, same.scale=FALSE)

## Pre-estimation of the item parameters (2PL model) (remove #)
# item.2PL<-rbind(itemParEst(data.ref, model="2PL"),
# itemParEst(data.focal, model="2PL"))
# difRaju(irtParam=item.2PL, same.scale=FALSE)

## Pre-estimation of the item parameters (constrained 3PL model)
# (remove #)
# item.3PL<-rbind(itemParEst(data.ref, model="3PL", c=0.05),
# itemParEst(data.focal, model="3PL", c=0.05))
# difRaju(irtParam=item.3PL, same.scale=FALSE)



